#include "mywidget.h"

#include <stdio.h>
#include <stdlib.h>
#include <time.h>

#include <qdir.h>
#include <qpopupmenu.h>

#include <zmessagebox.h>
#include <setup_api.h>

MyWidget::MyWidget()
	: ZMainWidget(0, "WPChanger", 0)
{
	SETUP_API sa;
	QString currwp;
	
	sa.getWallpaper(currwp);
	
	m_refreshTime = 30 * 1000 * 60;
	m_isRunning = FALSE;
	timer = new QTimer(this);
	
	connect( timer, SIGNAL(timeout()), SLOT(changeWP()) );
	
	m_ContentWidget = new MyContentWidget(this);
	m_ContentWidget->edit1->setText(currwp);
	m_ContentWidget->edit2->setText(QString("%1").arg(m_refreshTime));
	
	setupGUI();
};

MyWidget::~MyWidget()
{
	if (timer)	delete timer;
	if (m_CST)	delete m_CST;
	if (m_popupMenu)	delete m_popupMenu;
	if (m_popupMenuService)	delete m_popupMenuService;
	if (m_ContentWidget)	delete m_ContentWidget;
	//if (m_TitleBar)		delete m_TitleBar;
};

void MyWidget::setupGUI()
{
	m_CST = new UTIL_CST(this, "Get it!");
	setCSTWidget(m_CST);

	//connect(m_CST->getRightBtn(), SIGNAL(clicked()), SLOT(close()));
	m_CST->getRightBtn()->setEnabled(false);
	
	connect(m_CST->getMidBtn(), SIGNAL(clicked()), SLOT(HideOrClose()));
	
	m_popupMenu = new QPopupMenu(m_CST);
	m_popupMenuService = new QPopupMenu(m_CST);
	m_midStart = m_popupMenuService->insertItem("Start", this, SLOT(switchRefresh()));
	m_midStop  = m_popupMenuService->insertItem("Stop", this, SLOT(switchRefresh()));
	m_popupMenu->insertItem("Service", m_popupMenuService);
	m_popupMenu->insertSeparator();
	m_popupMenu->insertItem("About", this, SLOT(about()));
	m_popupMenu->insertSeparator();
	m_popupMenu->insertItem("Exit", this, SLOT(close()));
	m_CST->getLeftBtn()->setPopup(m_popupMenu);
	
	refreshStatus();
	
	setContentWidget(m_ContentWidget);
}

bool MyWidget::startRefresh(uint refreshTime, bool bNotify)
{
	m_refreshTime = refreshTime * 1000 * 60;
	return startRefresh(bNotify);
};

bool MyWidget::startRefresh(bool bNotify)
{
	if ((m_refreshTime >= 10 * 1000) && !m_isRunning) {
		m_isRunning = timer->start(m_refreshTime, FALSE);
	};
	if (bNotify) {
		if (m_isRunning) {
			printf("Timer started at %u msecs\n", m_refreshTime);
			ZMessageBox::information(this,
									ir.getIcon(RES_ICON_DLG_COMPLETE, false),
									"Wallpaper Changer started!",
									"OK");
		} else {
			printf("Timer faled to start at %u msecs\n", m_refreshTime);
			ZMessageBox::information(this,
									ir.getIcon(RES_ICON_DLG_ERROR, false),
									"Wallpaper Changer faled to start!",
									"OK");
		}
	};
	refreshStatus();
	return m_isRunning;
};	

void MyWidget::stopRefresh(bool bNotify)
{
	if (bNotify) {
		printf("Timer stopped\n");
		ZMessageBox::information(this,
								ir.getIcon(RES_ICON_DLG_ERROR, false),
								"Wallpaper Changer stopped!",
								"OK");
	};
	m_isRunning = FALSE;
	refreshStatus();
	timer->stop();
};

void MyWidget::refreshStatus()
{
	if (m_isRunning) {
		m_CST->getMidBtn()->setText("Hide");
	} else {
		m_CST->getMidBtn()->setText("Exit");
	}
	m_popupMenuService->setItemEnabled(m_midStart, !m_isRunning);
	m_popupMenuService->setItemEnabled(m_midStop, m_isRunning);
}

void MyWidget::switchRefresh()
{
	if (m_isRunning) {
		stopRefresh(TRUE);
	} else {
		startRefresh(TRUE);
	}
}

void MyWidget::HideOrClose()
{
	if (m_isRunning)
	{
		hide();
	} else {
		close();
	};
}

void MyWidget::changeWP()
{
	SETUP_API sa;
	QString currwp;
	QString newwp;
	
	sa.getWallpaper(currwp);
	QFileInfo currwpinfo(currwp);
	QDir dir = currwpinfo.dir(TRUE);
	dir.setNameFilter("*.jpg");
	dir.setFilter(QDir::Files);
	QStringList files = dir.entryList();

	srand (time(NULL));
	//printf("count: %u\n", files.count());
	newwp = currwp;
	if (files.count() > 1) {
		while (newwp == currwp) {
			newwp = dir.filePath(files[rand() % files.count()]);
		}
		printf("Setting '%s' as WP\n",  newwp.latin1());
		sa.setWallpaper(newwp);
	}		
};

	